@@ -88,10 +88,12 @@ def ProcessFiles(sourceFile):
                     for j in range(len(slicedUi)):
                         if re.fullmatch(r'\{\{.*?\}\} [a-zA-Z]+', slicedUi[j]) and re.search(r'(?<=\}\} ).+', slicedUi[j]).group().casefold() in enUi:
                             slicedUi[j] = ' '.join(re.split(r'(?<=\}\}) ', slicedUi[j])[::-1])
-                        if re.fullmatch(r'\*.*?\* [a-zA-Z]+', slicedItalic[j]) and re.search(r'(?<=\}\} ).+', slicedItalic[j]).group().casefold() in enUi:
-                            slicedItalic[j] = ' '.join(re.split(r'(?<=\}\}) ', slicedItalic[j])[::-1])
-                        if re.fullmatch(r'\*\*.*?\*\* [a-zA-Z]+', slicedBold[j]) and re.search(r'(?<=\}\} ).+', slicedBold[j]).group().casefold() in enUi:
-                            slicedBold[j] = ' '.join(re.split(r'(?<=\}\}) ', slicedBold[j])[::-1])
+                    for j in range(len(slicedItalic)):
+                        if re.fullmatch(r'\*.*?\* [a-zA-Z]+', slicedItalic[j]) and re.search(r'(?<=\* ).+', slicedItalic[j]).group().casefold() in enUi:
+                            slicedItalic[j] = ' '.join(re.split(r'(?<=\*) ', slicedItalic[j])[::-1])
+                    for j in range(len(slicedBold)):
+                        if re.fullmatch(r'\*\*.*?\*\* [a-zA-Z]+', slicedBold[j]) and re.search(r'(?<=\*\* ).+', slicedBold[j]).group().casefold() in enUi:
+                            slicedBold[j] = ' '.join(re.split(r'(?<=\*\*) ', slicedBold[j])[::-1])
                     sourceContent = ''.join(slicedUi)
                 slicedApple = list(filter(lambda x: x != '' and x is not None, mdRegex.split(sourceContent)))
                 for piece in slicedApple:
